==> fr-aster-9.3.0.1.tbz: aster/STA9.3/bibpyt/Messages/subdivise.py <==
#@ MODIF subdivise Messages  DATE 19/12/2007   AUTEUR ABBAS M.ABBAS 
# -*- coding: iso-8859-1 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2007  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
# (AT YOUR OPTION) ANY LATER VERSION.                                                  
#                                                                       
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
#                                                                       
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.        
# ======================================================================
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2006  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ======================================================================

def _(x) : return x

# Pour la mthode de subdivision

cata_msg={

# Plus de messages pour dveloppeur ==> ASSERT

# Messages utilisateurs
10: _("""Le nombre maximale d'itrations autorises ITER_GLOB_* est atteint. 
La mthode de subdivision ne peut pas faire d'extrapolation.
La subdivision UNIFORME est dclenche.
Cela peut etre du  une oscillation de l'erreur ou  une divergence.
   Nombre d'intervalle             = <%(i1)d>
   Niveau de subdivision           = <%(i2)d>
   Ratio sur le premier intervalle = <%(r1)E>
   Pas de Temps actuel             = <%(r2)E>"""),

11: _("""La mthode de subdivision ne peut pas faire d'extrapolation.
Il n'y a pas de convergence et la mthode de subdivision trouve un nombre
d'itration  convergence < au nombre donn sous le mot cl CONVERGENCE.
La subdivision UNIFORME est dclanche.
   Nombre d'intervalle             = <%(i1)d>
   Niveau de subdivision           = <%(i2)d>
   Ratio sur le premier intervalle = <%(r1)E>
   Pas de Temps actuel             = <%(r2)E>"""),

12: _("""Le nombre maximal de niveau de subdivision est atteint.
      SUBD_NIVEAU doit etre >= <%(i1)d>
      SUBD_NIVEAU est de     = <%(i2)d>
Conseil :
   Augmenter SUBD_NIVEAU. Il est galement possible d'ajuster SUBD_PAS_MINI pour
   imposer un incrment de temps en-dessous duquel on ne peut plus subdiviser.
   Si les 2 mots clefs SUBD_NIVEAU et SUBD_PAS_MINI sont utiliss la subdivision
   s'arrete ds que l'un des 2 critres est vrifi."""),

13: _("""Mthode de subdivision : %(k1)s"""),

14: _("""La subdivision est force, mthode UNIFORME.
   Nombre d'intervalle             = <%(i1)d>
   Niveau de subdivision           = <%(i2)d>
   Ratio sur le premier intervalle = <%(r1)E>
   Pas de Temps actuel             = <%(r2)E>"""),

15: _("""Le pas minimal de la subdivision est atteint.
   Pas de Temps actuel          = <%(r1)E>
   Pas de Temps minimum impos  = <%(r2)E>
   Niveau de subdivision        = <%(i1)d>
   Mthode de subdivision       = <%(k1)s>
Conseil :
   Diminuer SUBD_PAS_MINI. Il est galement possible d'ajuster SUBD_NIVEAU pour
   indiquer le nombre successif de subdivision d'un pas de temps.
   Si les 2 mots clefs SUBD_NIVEAU et SUBD_PAS_MINI sont utiliss la subdivision
   s'arrete ds que l'un des 2 critres est vrifi."""),

16: _("""Mthode extrapolation, convergence prvue en %(i1)d iterations pour un maximum
d'itrations autoris de %(i2)d."""),

17: _("""Itration n %(i1)d, poursuite autorise."""),

18: _("""Subdivision du pas de temps en %(i1)d intervalles. Le ratio sur le premier
intervalle est de %(r1)e.
   Niveau de subdivision = <%(i2)d>
   Pas de Temps actuel   = <%(r2)E>"""),

}

==> fr-aster-9.4.0.2.tbz: aster/STA9.4/bibpyt/Messages/subdivise.py <==
#@ MODIF subdivise Messages  DATE 28/07/2008   AUTEUR FLEJOU J-L.FLEJOU 
# -*- coding: iso-8859-1 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2007  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ======================================================================

def _(x) : return x

# Pour la mthode de subdivision

cata_msg={

# Plus de messages pour dveloppeur ==> ASSERT

# Messages utilisateurs
9: _("""La subdivisition utilise la mthode EXTRAPOLE.
Il n'y a pas eu de dtection de convergence alors que les critres sont atteints.
Cela peut arriver, si vous avez du contact avec une ractualisation gomtrique.
Aucune subdivision n'est faite. Pour information :
   Pour l'itration %(i1)d, RESI_GLOB_RELA = <%(r1)E> et doit tre infrieure  <%(r2)E>
   Pour l'itration %(i1)d, RESI_GLOB_MAXI = <%(r3)E> et doit tre infrieure  <%(r4)E>"""),

10: _("""Le nombre maximale d'itrations autorises ITER_GLOB_* est atteint.
La mthode de subdivision ne peut pas faire d'extrapolation.
La subdivision UNIFORME est dclenche. Cela peut etre du  une oscillation de l'erreur ou  une divergence.
   Nombre d'intervalle             = <%(i1)d>
   Niveau de subdivision           = <%(i2)d>
   Ratio sur le premier intervalle = <%(r1)E>
   Pas de Temps actuel             = <%(r2)E>"""),

11: _("""La mthode de subdivision ne peut pas faire d'extrapolation.
Il n'y a pas de convergence et la mthode de subdivision trouve un nombre
d'itration  convergence < au nombre donn sous le mot cl CONVERGENCE.
La subdivision UNIFORME est dclanche.
   Nombre d'intervalle             = <%(i1)d>
   Niveau de subdivision           = <%(i2)d>
   Ratio sur le premier intervalle = <%(r1)E>
   Pas de Temps actuel             = <%(r2)E>
Pour information :
   La rgression est faite sur <%(k1)s>
   La mthode calcule <%(r3)d> pour <%(r4)d>"""),

12: _("""Le nombre maximal de niveau de subdivision est atteint.
      SUBD_NIVEAU doit etre >= <%(i1)d>
      SUBD_NIVEAU est de     = <%(i2)d>
Conseil :
   Augmenter SUBD_NIVEAU. Il est galement possible d'ajuster SUBD_PAS_MINI pour
   imposer un incrment de temps en-dessous duquel on ne peut plus subdiviser.
   Si les 2 mots clefs SUBD_NIVEAU et SUBD_PAS_MINI sont utiliss la subdivision
   s'arrete ds que l'un des 2 critres est vrifi."""),

13: _("""Mthode de subdivision : %(k1)s"""),

14: _("""La subdivision est force, mthode UNIFORME.
   Nombre d'intervalle             = <%(i1)d>
   Niveau de subdivision           = <%(i2)d>
   Ratio sur le premier intervalle = <%(r1)E>
   Pas de Temps actuel             = <%(r2)E>"""),

15: _("""Le pas minimal de la subdivision est atteint.
   Pas de Temps actuel          = <%(r1)E>
   Pas de Temps minimum impos  = <%(r2)E>
   Niveau de subdivision        = <%(i1)d>
   Mthode de subdivision       = <%(k1)s>
Conseil :
   Diminuer SUBD_PAS_MINI. Il est galement possible d'ajuster SUBD_NIVEAU pour
   indiquer le nombre successif de subdivision d'un pas de temps.
   Si les 2 mots clefs SUBD_NIVEAU et SUBD_PAS_MINI sont utiliss la subdivision
   s'arrete ds que l'un des 2 critres est vrifi."""),

16: _("""Mthode extrapolation, convergence prvue en %(i1)d itrations pour un maximum autoris de %(i2)d."""),

17: _("""Itration %(i1)d, poursuite autorise."""),

18: _("""Subdivision du pas de temps en %(i1)d intervalles. Le ratio sur le premier intervalle est de %(r1)e.
   Niveau de subdivision = <%(i2)d>
   Pas de Temps actuel   = <%(r2)E>"""),

}
